package cn.com.ty.lift.business.common;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.library.dao.entity.LiftBrand;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.ty.lift.common.constants.RedisConstants;
import cn.com.ty.lift.common.model.AreaCode;
import cn.com.xwy.boot.web.dto.RestResponse;
import cn.hutool.core.util.ObjectUtil;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author bieao
 * @date 2019/12/19
 * @description 公共初始化数据
 */
@RestController
@RequestMapping("common")
public class CommonController {

    @Resource
    private RedisTemplate redisTemplate;

    /**
     * @return RestResponse 省、市、区树形结构列表
     * @description 查询省、市、区树形结构列表
     * @date 2019/12/4 10:23 AM
     */
    @PostMapping("area/list")
    public RestResponse areaList() {
        List<AreaCode> areaCodeList = (List<AreaCode>) redisTemplate.opsForValue().get(RedisConstants.RK_AREA_LIST);
        if (ObjectUtil.isEmpty(areaCodeList)) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, MessageUtils.get("msg.data.empty"));
        }
        return RestResponse.ok(areaCodeList, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.success"));
    }

    /**
     * @return RestResponse 电梯品牌列表
     * @description 查询电梯品牌列表
     * @date 2019/12/10 10:23 AM
     */
    @PostMapping("brand/list")
    public RestResponse list(){
        List<LiftBrand> liftBrandList = (List<LiftBrand>) redisTemplate.opsForValue().get(RedisConstants.RK_LIFT_BRAND_LIST);
        if (ObjectUtil.isEmpty(liftBrandList)) {
            return RestResponse.ok(null, ApiConstants.RESULT_NO_DATA, MessageUtils.get("msg.data.empty"));
        }
        return RestResponse.ok(liftBrandList, ApiConstants.RESULT_SUCCESS, MessageUtils.get("msg.query.success"));
    }
}
